@@ -25,13 +25,13 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import orca.cmdnames as cmdnames
-import orca.debug as debug
-import orca.focus_manager as focus_manager
-import orca.input_event as input_event
-import orca.scripts.default as default
-import orca.settings_manager as settings_manager
-import orca.scripts.toolkits.Gecko as Gecko
+from orca import cmdnames
+from orca import debug
+from orca import focus_manager
+from orca import input_event
+from orca.scripts import default
+from orca import settings_manager
+from orca.scripts.toolkits import Gecko
 from orca.ax_document import AXDocument
 from orca.ax_object import AXObject
 from orca.ax_text import AXText
@@ -39,94 +39,84 @@ from orca.ax_utilities import AXUtilities
 
 from .spellcheck import SpellCheck
 
-########################################################################
-#                                                                      #
-# The Thunderbird script class.                                        #
-#                                                                      #
-########################################################################
-
 class Script(Gecko.Script):
     """The script for Thunderbird."""
 
     def __init__(self, app):
-        """ Creates a new script for the given application.
-
-        Arguments:
-        - app: the application to create a script for.
-        """
-
         # Store the last autocompleted string for the address fields
         # so that we're not too 'chatty'.  See bug #533042.
         #
         self._lastAutoComplete = ""
 
-        if settings_manager.getManager().getSetting('sayAllOnLoad') is None:
-            settings_manager.getManager().setSetting('sayAllOnLoad', False)
-        if settings_manager.getManager().getSetting('pageSummaryOnLoad') is None:
-            settings_manager.getManager().setSetting('pageSummaryOnLoad', False)
+        if settings_manager.get_manager().get_setting('sayAllOnLoad') is None:
+            settings_manager.get_manager().set_setting('sayAllOnLoad', False)
+        if settings_manager.get_manager().get_setting('pageSummaryOnLoad') is None:
+            settings_manager.get_manager().set_setting('pageSummaryOnLoad', False)
 
         super().__init__(app)
 
-    def setupInputEventHandlers(self):
-        super().setupInputEventHandlers()
+    def setup_input_event_handlers(self):
+        """Defines the input event handlers for this script."""
 
-        self.inputEventHandlers["togglePresentationModeHandler"] = \
+        super().setup_input_event_handlers()
+
+        self.input_event_handlers["togglePresentationModeHandler"] = \
             input_event.InputEventHandler(
                 Script.togglePresentationMode,
                 cmdnames.TOGGLE_PRESENTATION_MODE)
 
-        self.inputEventHandlers["enableStickyFocusModeHandler"] = \
+        self.input_event_handlers["enableStickyFocusModeHandler"] = \
             input_event.InputEventHandler(
                 Script.enableStickyFocusMode,
                 cmdnames.SET_FOCUS_MODE_STICKY)
 
-        self.inputEventHandlers["enableStickyBrowseModeHandler"] = \
+        self.input_event_handlers["enableStickyBrowseModeHandler"] = \
             input_event.InputEventHandler(
                 Script.enableStickyBrowseMode,
                 cmdnames.SET_BROWSE_MODE_STICKY)
 
-    def getSpellCheck(self):
+    def get_spellcheck(self):
         """Returns the spellcheck support for this script."""
 
         return SpellCheck(self)
 
-    def getAppPreferencesGUI(self):
+    def get_app_preferences_gui(self):
         """Return a GtkGrid containing the application unique configuration
         GUI items for the current application."""
 
-        grid = super().getAppPreferencesGUI()
+        grid = super().get_app_preferences_gui()
 
         self._sayAllOnLoadCheckButton.set_active(
-            settings_manager.getManager().getSetting('sayAllOnLoad'))
+            settings_manager.get_manager().get_setting('sayAllOnLoad'))
         self._pageSummaryOnLoadCheckButton.set_active(
-            settings_manager.getManager().getSetting('pageSummaryOnLoad'))
+            settings_manager.get_manager().get_setting('pageSummaryOnLoad'))
 
-        spellcheck = self.spellcheck.getAppPreferencesGUI()
+        spellcheck = self.spellcheck.get_app_preferences_gui()
         grid.attach(spellcheck, 0, len(grid.get_children()), 1, 1)
         grid.show_all()
 
         return grid
 
-    def getPreferencesFromGUI(self):
+    def get_preferences_from_gui(self):
         """Returns a dictionary with the app-specific preferences."""
 
-        prefs = super().getPreferencesFromGUI()
+        prefs = super().get_preferences_from_gui()
         prefs['sayAllOnLoad'] = self._sayAllOnLoadCheckButton.get_active()
         prefs['pageSummaryOnLoad'] = self._pageSummaryOnLoadCheckButton.get_active()
-        prefs.update(self.spellcheck.getPreferencesFromGUI())
+        prefs.update(self.spellcheck.get_preferences_from_gui())
 
         return prefs
 
-    def locusOfFocusChanged(self, event, oldFocus, newFocus):
+    def locus_of_focus_changed(self, event, old_focus, new_focus):
         """Handles changes of focus of interest to the script."""
 
-        if self.spellcheck.isSuggestionsItem(newFocus):
-            includeLabel = not self.spellcheck.isSuggestionsItem(oldFocus)
-            self.updateBraille(newFocus)
+        if self.spellcheck.isSuggestionsItem(new_focus):
+            includeLabel = not self.spellcheck.isSuggestionsItem(old_focus)
+            self.update_braille(new_focus)
             self.spellcheck.presentSuggestionListItem(includeLabel=includeLabel)
             return
 
-        super().locusOfFocusChanged(event, oldFocus, newFocus)
+        super().locus_of_focus_changed(event, old_focus, new_focus)
 
     def useFocusMode(self, obj, prevObj=None):
         if self.utilities.isEditableMessage(obj):
@@ -139,25 +129,25 @@ class Script(Gecko.Script):
         return super().useFocusMode(obj, prevObj)
 
     def enableStickyBrowseMode(self, inputEvent, forceMessage=False):
-        if self.utilities.isEditableMessage(focus_manager.getManager().get_locus_of_focus()):
+        if self.utilities.isEditableMessage(focus_manager.get_manager().get_locus_of_focus()):
             return
 
         super().enableStickyBrowseMode(inputEvent, forceMessage)
 
     def enableStickyFocusMode(self, inputEvent, forceMessage=False):
-        if self.utilities.isEditableMessage(focus_manager.getManager().get_locus_of_focus()):
+        if self.utilities.isEditableMessage(focus_manager.get_manager().get_locus_of_focus()):
             return
 
         super().enableStickyFocusMode(inputEvent, forceMessage)
 
     def togglePresentationMode(self, inputEvent, documentFrame=None):
         if self._inFocusMode \
-           and self.utilities.isEditableMessage(focus_manager.getManager().get_locus_of_focus()):
+           and self.utilities.isEditableMessage(focus_manager.get_manager().get_locus_of_focus()):
             return
 
         super().togglePresentationMode(inputEvent, documentFrame)
 
-    def onFocusedChanged(self, event):
+    def on_focused_changed(self, event):
         """Callback for object:state-changed:focused accessibility events."""
 
         if not event.detail1:
@@ -166,20 +156,20 @@ class Script(Gecko.Script):
         self._lastAutoComplete = ""
         obj = event.source
         if self.spellcheck.isAutoFocusEvent(event):
-            focus_manager.getManager().set_locus_of_focus(event, event.source, False)
-            self.updateBraille(event.source)
+            focus_manager.get_manager().set_locus_of_focus(event, event.source, False)
+            self.update_braille(event.source)
 
         if not self.utilities.inDocumentContent(obj):
-            super().onFocusedChanged(event)
+            super().on_focused_changed(event)
             return
 
         if self.utilities.isEditableMessage(obj):
-            super().onFocusedChanged(event)
+            super().on_focused_changed(event)
             return
 
-        super().onFocusedChanged(event)
+        super().on_focused_changed(event)
 
-    def onBusyChanged(self, event):
+    def on_busy_changed(self, event):
         """Callback for object:state-changed:busy accessibility events."""
 
         if self.utilities.isEditableMessage(event.source):
@@ -190,16 +180,16 @@ class Script(Gecko.Script):
 
         obj = event.source
         if self.utilities.isDocument(obj) and not event.detail1:
-            focus = focus_manager.getManager().get_locus_of_focus()
+            focus = focus_manager.get_manager().get_locus_of_focus()
             if AXObject.get_name(focus) \
                 and (AXUtilities.is_frame(focus) or AXUtilities.is_page_tab(focus)):
-                focus_manager.getManager().set_locus_of_focus(event, event.source, False)
+                focus_manager.get_manager().set_locus_of_focus(event, event.source, False)
 
             if self.utilities.inDocumentContent():
                 self.speakMessage(AXObject.get_name(obj))
                 self._presentMessage(obj)
 
-    def onCaretMoved(self, event):
+    def on_caret_moved(self, event):
         """Callback for object:text-caret-moved accessibility events."""
 
         if self.utilities.isEditableMessage(event.source):
@@ -209,9 +199,9 @@ class Script(Gecko.Script):
             if self.spellcheck.isActive():
                 return
 
-        super().onCaretMoved(event)
+        super().on_caret_moved(event)
 
-    def onSelectionChanged(self, event):
+    def on_selection_changed(self, event):
         """Callback for object:state-changed:showing accessibility events."""
 
         # We present changes when the list has focus via focus-changed events.
@@ -222,18 +212,18 @@ class Script(Gecko.Script):
         if AXUtilities.is_combo_box(parent) and not AXUtilities.is_focused(parent):
             return
 
-        super().onSelectionChanged(event)
+        super().on_selection_changed(event)
 
-    def onSensitiveChanged(self, event):
+    def on_sensitive_changed(self, event):
         """Callback for object:state-changed:sensitive accessibility events."""
 
         if event.source == self.spellcheck.getChangeToEntry() \
            and self.spellcheck.presentCompletionMessage():
             return
 
-        super().onSensitiveChanged(event)
+        super().on_sensitive_changed(event)
 
-    def onShowingChanged(self, event):
+    def on_showing_changed(self, event):
         """Callback for object:state-changed:showing accessibility events."""
 
         # TODO - JD: Once there are separate scripts for the Gecko toolkit
@@ -243,25 +233,21 @@ class Script(Gecko.Script):
 
         if event.detail1 and self.utilities.isMenuWithNoSelectedChild(event.source) \
            and self.utilities.topLevelObjectIsActiveWindow(event.source):
-            focus_manager.getManager().set_locus_of_focus(event, event.source, True)
+            focus_manager.get_manager().set_locus_of_focus(event, event.source, True)
             return
 
-        default.Script.onShowingChanged(self, event)
+        default.Script.on_showing_changed(self, event)
 
-    def onTextDeleted(self, event):
-        """Called whenever text is from an object.
-
-        Arguments:
-        - event: the Event
-        """
+    def on_text_deleted(self, event):
+        """Callback for object:text-changed:delete accessibility events."""
 
         if AXUtilities.is_label(event.source) \
            and AXUtilities.is_status_bar(AXObject.get_parent(event.source)):
             return
 
-        super().onTextDeleted(event)
+        super().on_text_deleted(event)
 
-    def onTextInserted(self, event):
+    def on_text_inserted(self, event):
         """Callback for object:text-changed:insert accessibility events."""
 
         parent = AXObject.get_parent(event.source)
@@ -282,7 +268,7 @@ class Script(Gecko.Script):
         # address so that we're not too "chatty." See bug #533042.
         if AXUtilities.is_autocomplete(parent):
             if len(event.any_data) == 1:
-                default.Script.onTextInserted(self, event)
+                default.Script.on_text_inserted(self, event)
                 return
 
             if self._lastAutoComplete and self._lastAutoComplete in event.any_data:
@@ -291,14 +277,14 @@ class Script(Gecko.Script):
             # Mozilla cannot seem to get their ":system" suffix right
             # to save their lives, so we'll add yet another sad hack.
             if isSystemEvent or AXText.has_selected_text(event.source):
-                voice = self.speechGenerator.voice(obj=event.source, string=event.any_data)
+                voice = self.speech_generator.voice(obj=event.source, string=event.any_data)
                 self.speakMessage(event.any_data, voice=voice)
                 self._lastAutoComplete = event.any_data
                 return
 
-        super().onTextInserted(event)
+        super().on_text_inserted(event)
 
-    def onTextSelectionChanged(self, event):
+    def on_text_selection_changed(self, event):
         """Callback for object:text-selection-changed accessibility events."""
 
         obj = event.source
@@ -312,16 +298,16 @@ class Script(Gecko.Script):
                 self.spellcheck.setDocumentPosition(obj, selStart)
             return
 
-        super().onTextSelectionChanged(event)
+        super().on_text_selection_changed(event)
 
-    def onNameChanged(self, event):
+    def on_name_changed(self, event):
         """Callback for object:property-change:accessible-name events."""
 
         if AXObject.get_name(event.source) == self.spellcheck.getMisspelledWord():
             self.spellcheck.presentErrorDetails()
             return
 
-        super().onNameChanged(event)
+        super().on_name_changed(event)
 
     def _presentMessage(self, documentFrame):
         """Presents the first line of the message, or the entire message,
@@ -329,43 +315,43 @@ class Script(Gecko.Script):
 
         [obj, offset] = self.utilities.findFirstCaretContext(documentFrame, 0)
         self.utilities.setCaretPosition(obj, offset)
-        self.updateBraille(obj)
+        self.update_braille(obj)
 
-        if settings_manager.getManager().getSetting('pageSummaryOnLoad'):
+        if settings_manager.get_manager().get_setting('pageSummaryOnLoad'):
             tokens = ["THUNDERBIRD: Getting page summary for", documentFrame]
             debug.printTokens(debug.LEVEL_INFO, tokens, True)
             summary = AXDocument.get_document_summary(documentFrame)
             if summary:
                 self.presentMessage(summary)
 
-        if not settings_manager.getManager().getSetting('sayAllOnLoad'):
+        if not settings_manager.get_manager().get_setting('sayAllOnLoad'):
             msg = "THUNDERBIRD: SayAllOnLoad is False. Presenting line."
             debug.printMessage(debug.LEVEL_INFO, msg, True)
             contents = self.utilities.getLineContentsAtOffset(obj, offset)
             self.speakContents(contents)
             return
 
-        if settings_manager.getManager().getSetting('enableSpeech'):
+        if settings_manager.get_manager().get_setting('enableSpeech'):
             msg = "THUNDERBIRD: SayAllOnLoad is True and speech is enabled"
             debug.printMessage(debug.LEVEL_INFO, msg, True)
-            self.sayAll(None)
+            self.say_all(None)
 
-    def onWindowActivated(self, event):
+    def on_window_activated(self, event):
         """Callback for window:activate accessibility events."""
 
-        super().onWindowActivated(event)
+        super().on_window_activated(event)
         if not self.spellcheck.isCheckWindow(event.source):
             self.spellcheck.deactivate()
             return
 
         self.spellcheck.presentErrorDetails()
         entry = self.spellcheck.getChangeToEntry()
-        focus_manager.getManager().set_locus_of_focus(None, entry, False)
-        self.updateBraille(entry)
+        focus_manager.get_manager().set_locus_of_focus(None, entry, False)
+        self.update_braille(entry)
 
-    def onWindowDeactivated(self, event):
+    def on_window_deactivated(self, event):
         """Callback for window:deactivate accessibility events."""
 
-        super().onWindowDeactivated(event)
+        super().on_window_deactivated(event)
         self.spellcheck.deactivate()
         self.utilities.clearContentCache()
