@@ -25,9 +25,9 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2013-2019 Igalia, S.L."
 __license__   = "LGPL"
 
-import orca.debug as debug
-import orca.focus_manager as focus_manager
-import orca.scripts.default as default
+from orca import debug
+from orca import focus_manager
+from orca.scripts import default
 from orca.ax_object import AXObject
 from orca.ax_utilities import AXUtilities
 
@@ -36,13 +36,10 @@ from .script_utilities import Utilities
 
 class Script(default.Script):
 
-    def __init__(self, app):
-        super().__init__(app)
-
-    def getUtilities(self):
+    def get_utilities(self):
         return Utilities(self)
 
-    def onCaretMoved(self, event):
+    def on_caret_moved(self, event):
         """Callback for object:text-caret-moved accessibility events."""
 
         if AXUtilities.is_accelerator_label(event.source):
@@ -50,9 +47,9 @@ class Script(default.Script):
             debug.printMessage(debug.LEVEL_INFO, msg, True)
             return
 
-        super().onCaretMoved(event)
+        super().on_caret_moved(event)
 
-    def onFocusedChanged(self, event):
+    def on_focused_changed(self, event):
         """Callback for object:state-changed:focused accessibility events."""
 
         if not event.detail1:
@@ -80,9 +77,9 @@ class Script(default.Script):
             debug.printTokens(debug.LEVEL_INFO, tokens, True)
 
         if AXUtilities.is_focused(event.source):
-            super().onFocusedChanged(event)
+            super().on_focused_changed(event)
             return
 
         msg = "QT: WARNING - source lacks focused state. Setting focus anyway."
         debug.printMessage(debug.LEVEL_INFO, msg, True)
-        focus_manager.getManager().set_locus_of_focus(event, event.source)
+        focus_manager.get_manager().set_locus_of_focus(event, event.source)
