@@ -60,7 +60,6 @@ userCustomizableSettings = [
     "enableMnemonicSpeaking",
     "enablePositionSpeaking",
     "enableBraille",
-    "enableBrailleContext",
     "disableBrailleEOL",
     "brailleVerbosityLevel",
     "brailleRolenameStyle",
@@ -77,7 +76,6 @@ userCustomizableSettings = [
     "sayAllStyle",
     "keyboardLayout",
     "speakBlankLines",
-    "speakMultiCaseStringsAsWords",
     "speakNumbersAsDigits",
     "speakMisspelledIndicator",
     "enabledSpokenTextAttributes",
@@ -213,7 +211,7 @@ speechServerInfo             = None # None means let the factory decide.
 speechSystemOverride         = None
 enableSpeech                 = True
 silenceSpeech                = False
-enableTutorialMessages       = False
+enableTutorialMessages       = True
 enableMnemonicSpeaking       = False
 enablePositionSpeaking       = False
 enableSpeechIndentation      = False
@@ -229,7 +227,6 @@ speakCellSpan                = True
 speakCellHeaders             = True
 speakSpreadsheetCoordinates  = True
 alwaysSpeakSelectedSpreadsheetRange = False
-speakMultiCaseStringsAsWords = False
 speakNumbersAsDigits         = False
 speakMisspelledIndicator     = True
 useColorNames                = True
@@ -257,7 +254,6 @@ sayAllContextTable           = True
 # Braille
 enableBraille                  = True
 enableBrailleMonitor           = False
-enableBrailleContext           = True
 enableFlashMessages            = True
 brailleFlashTime               = 5000
 flashIsPersistent              = False
